[LON-CAPA-cvs] cvs: loncom /xml lonxml.pm

foxr lon-capa-cvs-allow@mail.lon-capa.org
Mon, 22 Oct 2007 09:27:51 -0000


foxr		Mon Oct 22 05:27:51 2007 EDT

  Modified files:              
    /loncom/xml	lonxml.pm 
  Log:
  Some linguistic changes to reflect the fact that response_id's are being 
  passed to the bubble tracking stuff.
  
  
Index: loncom/xml/lonxml.pm
diff -u loncom/xml/lonxml.pm:1.465 loncom/xml/lonxml.pm:1.466
--- loncom/xml/lonxml.pm:1.465	Tue Oct 16 19:20:05 2007
+++ loncom/xml/lonxml.pm	Mon Oct 22 05:27:50 2007
@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # XML Parser Module 
 #
-# $Id: lonxml.pm,v 1.465 2007/10/16 23:20:05 albertel Exp $
+# $Id: lonxml.pm,v 1.466 2007/10/22 09:27:50 foxr Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -1066,28 +1066,28 @@
 Optional Arguments:
   $increment - amount to increment by (defaults to 1)
                Also 1 if the value is negative or zero.
-  $part_id   - optional part id.. during analysis, this
-               indicates whic part of a problem is being
+  $response_id - The id of the response to record.  This
+               indicates whicn part of which  problem is being
                counted.
 
 =cut
 
 sub increment_counter {
-    my ($increment, $part_id) = @_;
+    my ($increment, $response_id) = @_;
     if (!defined($increment) || $increment le 0) {
 	$increment = 1;
     }
     $Apache::lonxml::counter += $increment;
 
     # If the caller supplied the part_id parameter, 
     # Maintain its counter.. creating if necessary.
 
-    if(defined($part_id)) {
-	if (!defined($Apache::lonxml::counters_per_part{$part_id})) {
-	    $Apache::lonxml::counters_per_part{$part_id} = 0;
+    if(defined($response_id)) {
+	if (!defined($Apache::lonxml::counters_per_part{$response_id})) {
+	    $Apache::lonxml::counters_per_part{$response_id} = 0;
 	}
-	$Apache::lonxml::counters_per_part{$part_id} += $increment;
-	my $new_value = $Apache::lonxml::counters_per_part{$part_id};
+	$Apache::lonxml::counters_per_part{$response_id} += $increment;
+	my $new_value = $Apache::lonxml::counters_per_part{$response_id};
     }
 	
     $Apache::lonxml::counter_changed=1;
@@ -1148,20 +1148,20 @@
 
 =pod
 
-=item  bubble_lines_for_part(part_id)
+=item  bubble_lines_for_part(response_id)
 
 Returns the number of lines required to get a response for
-$part_id (this is just $Apache::lonxml::counters_per_part{$part_id}
+$response_id (this is just $Apache::lonxml::counters_per_part{$response_id}
 
 =cut
 
 sub bubble_lines_for_part {
-    my ($part_id) = @_;
+    my ($response_id) = @_;
 
-    if (!defined($Apache::lonxml::counters_per_part{$part_id})) {
+    if (!defined($Apache::lonxml::counters_per_part{$response_id})) {
 	return 0;
     } else {
-	return $Apache::lonxml::counters_per_part{$part_id};
+	return $Apache::lonxml::counters_per_part{$response_id};
     }
 
 }
@@ -1182,7 +1182,7 @@
 
 =pod
 
-=item set_bubble_lines(part_id, value)
+=item set_bubble_lines(response_id, value)
 
 If there is a problem part, that for whatever reason
 requires bubble lines that are not
@@ -1192,9 +1192,9 @@
 =cut
 
 sub set_bubble_lines {
-    my ($part_id, $value) = @_;
+    my ($response_id, $value) = @_;
 
-    $Apache::lonxml::counters_per_part{$part_id} = $value;
+    $Apache::lonxml::counters_per_part{$response_id} = $value;
 }
 
 =pod
@@ -1066,28 +1066,28 @@
     $Apache::lonxml::counter += $increment;
 
-    # If the caller supplied the part_id parameter, 
+    # If the caller supplied the response_id parameter, 
     # Maintain its counter.. creating if necessary.
 